==> campsite-2.5.1.tar.gz: campsite/implementation/management/priv/lang/zh/globals.php <==
<?php
regGS("Account", "");
regGS("Items per page", "");
regGS("Cannot create file \"$1\"", "");
regGS("URL \"$1\" is invalid or is not an image.", "");
regGS("URL \"$1\" is not an image.", "");
regGS("Add new", "");
regGS("CAMPSITE", "CAMPSITE");
regGS("Home", "首页");
regGS("Logout", "注销");
regGS("You are logged in as $1", "");
regGS("More...", "");
regGS("Content", "");
regGS("Languages", "语言");
regGS("Countries", "国家");
regGS("Templates", "模版");
regGS("Topics", "主题");
regGS("Configure", "");
regGS("Image Archive", "");
regGS("Add Article", "");
regGS("Fields", "字段");
regGS("Delete", "删除");
regGS("Type", "输入");
regGS("Name", "名称");
regGS("Keyword", "关键词");
regGS("Native name", "本地名称");
regGS("Code", "号码");
regGS("Code page", "号码页");
regGS("Edit", "编辑");
regGS("Reader", "读者");
regGS("Access", "访问");
regGS("Login", "登陆");
regGS("Password", "密码");
regGS("Site", "地址");
regGS("Currency", "货币");
regGS("Path", "路径");
regGS("Go up", "向上");
regGS("URL", "");
regGS("Order", "");
regGS("Hide", "");
regGS("Duplicate", "复制");
regGS("Insert Internal Link", "");
regGS("Subscription", "");
regGS("expires", "");
regGS("starts", "");
regGS("before", "");
regGS("after", "");
regGS("on", "");
regGS("status", "");
regGS("active", "");
regGS("inactive", "");
regGS("Subscribers", "");
regGS("Staff", "");
regGS("Select destination", "");
regGS("No languages", "无语言");
regGS("---Select language---", "－－选择语言－－");
regGS("No publications", "无出版物");
regGS("---Select publication---", "－－选择出版物－－");
regGS("No issues", "无议题");
regGS("---Select issue---", "－－选择议题－－");
regGS("No sections", "无区");
regGS("---Select section---", "－－选择区－－");
regGS("No articles", "无文章");
regGS("---Select article---", "－－选择文章－－");
regGS("Language", "语言");
regGS("Translation", "翻译");
regGS("Country", "国家");
regGS("Account name", "");
regGS("Definition", "定义");
regGS("Publication", "出版物");
regGS("Default language", "默认语言");
regGS("Time Unit", "时间单位");
regGS("Unit Cost", "单位码");
regGS("Subscriptions", "订阅");
regGS("Issue", "问题");
regGS("Number", "数字");
regGS("Section", "区");
regGS("Keywords", "关键词");
regGS("Topic", "主题");
regGS("URL Name", "");
regGS("Left to pay", "");
regGS("Active", "");
regGS("Paid", "");
regGS("Trial", "");
regGS("Next", "下一个");
regGS("Previous", "上一个");
regGS("Translate", "翻译");
regGS("Details", "详情");
regGS("View", "查看");
regGS("Scheduled Publishing", "");
regGS("Time", "");
regGS("Action", "");
regGS("Schedule a new action", "");
regGS("No entries.", "");
regGS("Scheduling a new publish action", "");
regGS("Delete scheduled publish action", "");
regGS("The $1 action has been scheduled on $2", "");
regGS("Date/Time", "");
regGS("You must select an action.", "");
regGS("There was an error scheduling the $1 action on $2", "");
regGS("You do not have the right to schedule issues or articles for automatic publishing.", "");
regGS("The action scheduled on $1 could not be deleted.", "");
regGS("Front page", "");
regGS("Section page", "");
regGS("Show on front page", "");
regGS("Remove from front page", "");
regGS("Show on section page", "");
regGS("Remove from section page", "");
regGS("Actions", "");
regGS("Publishing", "");
regGS("Show", "");
regGS("Remove", "");
regGS("days", "天数");
regGS("Article Types", "文章类型");
regGS("Staff User Types", "");
regGS("Publications", "出版物");
regGS("Issues", "问题");
regGS("Sections", "区域");
regGS("Articles", "文章");
regGS("Images", "图片");
regGS("Nr", "号码");
regGS("Change", "变化");
regGS("Add new issue", "添加新论题");
regGS("Add new topic", "添加新主题");
regGS("Delete topic", "删除主题");
regGS("Edit languages", "");
regGS("Section Template", "");
regGS("Article Template", "");
regGS("Default Language", "默认语言");
regGS("Countries Subscription Default Time", "");
regGS("Pay Period", "付款期");
regGS("Info", "信息");
regGS("Trial Period", "试验期");
regGS("Paid Period", "已付期");
regGS("Preview", "预览");
regGS("You must complete the $1 field.", "您必须完成$1字段");
regGS("Error", "");
regGS("Invalid input: $1", "");
regGS("Language does not exist.", "");
regGS("Keyword does not exist.", "");
regGS("Publication does not exist.", "无此出版物");
regGS("Country does not exist.", "");
regGS("Issue does not exist.", "");
regGS("Topic does not exist.", "无此主题");
regGS("You must select a language.", "您必须选择一种语言");
regGS("Section does not exist.", "");
regGS("No articles.", "无此文字");
regGS("Article does not exist.", "");
regGS("Image does not exist.", "");
regGS("Access denied", "拒绝访问");
regGS("There was an error reading the language parameter.", "");
regGS("There was an error reading the publication parameter.", "");
regGS("There was an error reading the issue parameter.", "");
regGS("There was an error reading request parameters.", "");
regGS("Invalid value of user type parameter", "");
regGS("Invalid article identifier", "");
regGS("Invalid destination section selected", "");
regGS("Internal error: identifiers not initialized", "");
regGS("Internal database error", "");
regGS("Invalid parameters received", "");
regGS("Add new article", "添加新文章");
regGS("Status", "状态");
regGS("No such article.", "无此文章");
regGS("Published", "已发布");
regGS("Not published", "未发布");
regGS("Submitted", "已提交");
regGS("New", "新");
regGS("Article", "文章");
regGS("Publish", "发布");
regGS("Unpublish", "不发布");
regGS("Unlock", "解锁");
regGS("Uploaded", "已上载");
regGS("(yyyy-mm-dd)", "yyyy-mm-dd");
regGS("YYYY-MM-DD", "YYYY-MM-DD");
regGS("Submit", "提交");
regGS("Field", "字段");
regGS("Edit details", "编辑详情");
regGS("No such image.", "无此图片");
regGS("Image", "图片");
regGS("Description", "描述");
regGS("Photographer", "摄影");
regGS("Place", "地点");
regGS("Date", "日期");
regGS("Thumbnail", "");
regGS("In use", "");
regGS("Miscellaneous", "");
regGS("Identifier", "");
regGS("Additional searches", "");
regGS("Most Recently Added", "");
regGS("Most Recently Modified", "");
regGS("$1 images found", "");
regGS("Reset search conditions", "");
regGS("Preview issue", "");
regGS("Image number", "图片号码");
regGS("Users", "用户");
regGS("User may add/change publications", "用户可以添加/改变发布");
regGS("User may delete publications", "用户可以删除发布");
regGS("User may add/change issues", "用户可以添加/变化问题");
regGS("User may delete issues", "用户可以删除问题");
regGS("User may add/change sections", "用户可以添加/改变区域");
regGS("User may delete sections", "用户可以删除区域");
regGS("User may add articles", "用户可添加文章");
regGS("User may change articles", "用户可以改编文章");
regGS("User may delete articles", "用户可删除文章");
regGS("User may add images", "用户可添加图片");
regGS("User may change images", "用户可替换图片");
regGS("User may delete images", "用户可删除图片");
regGS("User may add templates", "用户可添加模版");
regGS("User may delete templates", "用户可删除模版");
regGS("User may add/change staff accounts and passwords", "");
regGS("User may add/change subscribers accounts and passwords", "");
regGS("User may delete staff accounts", "");
regGS("User may manage user subscriptions", "用户可管理用户订阅");
regGS("User may manage account types", "用户可管理帐户类型");
regGS("User may add/change article types", "用户可添加/变化文章类型");
regGS("User may delete article types", "用户可删除文章类型");
regGS("User may manage templates", "");
regGS("User may add/change country entries", "");
regGS("User may add languages and manage language information", "用户可添加/管理语言信息");
regGS("User may delete languages", "用户可删除语言");
regGS("User will be notified on several events", "用户将被告知");
regGS("User may view audit logs", "用户可查看日志");
regGS("User may add/change country names", "用户可添加/改变国家名");
regGS("User may delete country entries", "用户可删除国家入口");
regGS("User may manage localizer", "用户可管理本地");
regGS("User may manage indexer", "用户可管理索引者");
regGS("User may publish articles", "用户可发布文章");
regGS("User may manage topics", "用户可管理主题");
regGS("User may use bold", "");
regGS("User may use italic", "");
regGS("User may use underline", "");
regGS("User may use strikethrough", "");
regGS("User may change text alignment", "");
regGS("User may copy, cut, and paste", "");
regGS("User may undo/redo", "");
regGS("User may change text direction", "");
regGS("User may set indents", "");
regGS("User may add links", "");
regGS("User may add subheads", "");
regGS("User may insert images", "");
regGS("User may view the HTML source", "");
regGS("User may enlarge the editor", "");
regGS("User may change the font face", "");
regGS("User may change the font size", "");
regGS("User may create bulleted lists", "");
regGS("User may create numbered lists", "");
regGS("User may insert tables", "");
regGS("User may insert horizontal rules", "");
regGS("User may change the font color", "");
regGS("User may use superscripts", "");
regGS("User may use subscripts", "");
regGS("User may restart the template engine", "");
regGS("Administrative tasks", "");
regGS("Restart the template engine", "");
regGS("The template engine was (re)started.", "");
regGS("The template engine could not be restarted! Please verify if the template engine was started by other user than $1.", "");
regGS("An user type with the name '$1' already exists.", "");
regGS("Localizer", "");
regGS("Staff/Subscribers Management", "");
regGS("Editor Basic Settings", "");
regGS("Editor Advanced Font Settings", "");
regGS("Editor Table Settings", "");
regGS("Editor Miscellaneous Settings", "");
regGS("Updating user types permissions", "");
regGS("Adding new translation", "添加新翻译");
regGS("No more languages.", "无更多语言");
regGS("The $1 field may only contain letters, digits and underscore (_) character.", "");
regGS("Add new publication", "添加新发布");
regGS("Upload new template", "上载新模版");
regGS("Add new staff member", "");
regGS("Add new subscriber", "");
regGS("Add new user type", "添加新用户类型");
regGS("Add new article type", "添加新文章类型");
regGS("Add new country", "添加新国家");
regGS("Add new language", "添加新语言");
regGS("Add new section", "添加新区");
regGS("View logs", "查看日志");
regGS("Change your password", "修改你的密码");
regGS("Your Articles", "你的文章");
regGS("Submitted Articles", "提交文章");
regGS("Logs", "日志");
regGS("There are $1 article(s) left.", "还有$1篇文章");
regGS("There are $1 issues(s) left.", "");
regGS("There are $1 section(s) left.", "还有$1区");
regGS("There are $1 publication(s) left.", "还有$1发布");
regGS("There are $1 keywords(s) left.", "");
regGS("There are $1 countries left.", "还有$1个国家");
regGS("Name <SMALL>(click to edit)</SMALL>", "");
regGS("User account", "帐户");
regGS("No such user account.", "无此帐户");
regGS("Add new subscription", "添加新订阅");
regGS("You do not have the right to add subscriptions.", "你没有添加订阅的权限");
regGS("Adding subscription", "添加订阅");
regGS("The section could not be added.", "不能添加区");
regGS("Delete subscription", "删除订阅");
regGS("You do not have the right to delete subscriptions.", "你没有删除订阅的权限");
regGS("No such subscription.", "无此订阅");
regGS("The section $1 could not be deleted.", "$1区不能被删除");
regGS("The topic $1 could not be deleted.", "$1主题不能被删除");
regGS("Yes", "是");
regGS("No", "否");
regGS("Close", "");
regGS("No issues.", "无问题");
regGS("No subscriptions.", "");
regGS("Back to Edit Article", "");
regGS("Adding new topic", "添加新主题");
regGS("Topic $1 added", "主题$1已添加");
regGS("The topic could not be added.", "主题不能被添加");
regGS("Add another topic", "添加另一个主题");
regGS("Deleting topic", "删除主题");
regGS("There are $1 subtopics left.", "还有$1子主题");
regGS("Topic $1 deleted", "主题$1已删除");
regGS("You do not have the right to change topic name.", "你没有权限改变主题名");
regGS("Topic $1 updated", "主题$1已更新");
regGS("The topic name could not be updated.", "主题名不能更新");
regGS("Change topic name", "改变主题名");
regGS("Delete topic $1", "删除主题$1");
regGS("No topics", "无主题");
regGS("The topic $1 has been deleted.", "主题$1已被删除");
regGS("There are $1 articles using the topic.", "有$1篇文章用此主题");
regGS("You must fill in the $1 field.", "你必须填写$1字段");
regGS("You do not have the right to add articles.", "您无权添加文章");
regGS("Start", "开始");
regGS("Days", "天数");
regGS("(YYYY-MM-DD)", "YYYY-MM-DD");
regGS("The sections were added successfully.", "区被成功添加");
regGS("The sections could not be added successfully. Some of them were already added !", "区未成功添加，其中一些已经存在");
regGS("This article cannot be previewed. Please make sure it has the article template selected.", "");
regGS("This article cannot be previewed. Please make sure it has the front page template selected.", "");
regGS("Add another", "添加另一个");
regGS("Cancel", "取消");
regGS("Done", "完成");
regGS("New Field", "");
regGS("OK", "成功");
regGS("Save", "");
regGS("Search", "搜索");
regGS("Add New Field", "");
regGS("Make a selection", "");
regGS("You must input a number greater than 0 into the $1 field.", "");
regGS("You must input a valid date.", "");
regGS("Add new field", "增加新字段");
regGS("Article automatic publishing schedule", "");
regGS("Are you sure you want to delete this scheduled action?", "");
regGS("Unlink", "");
regGS("Are you sure you want to delete the image \'$1\'?", "");
regGS("No such issue.", "无此问题");
regGS("No such section.", "无此区");
regGS("Are you sure you want to delete the subscription to the publication $1?", "");
regGS("Are you sure you want to deactivate the subscription?", "");
regGS("Are you sure you want to activate the subscription?", "");
regGS("Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.", "");
regGS("GB", "");
regGS("MB", "");
regGS("KB", "");
regGS("bytes", "");
regGS("Attach", "");
regGS("Back", "");
regGS("File", "");
regGS("Save and Close", "");
regGS("Add", "增加");
regGS("User name", "用户名");
regGS("User Types", "用户类型");
regGS("Subscription Default Time", "默认订阅时间");
regGS("No such language.", "无此语言");
regGS("No such infotype.", "无此类型");
regGS("No such keyword.", "无此关键字");
regGS("No such country.", "无此国家");
regGS("User may add/change user accounts and passwords", "用户可添加/删除帐户与密码");
regGS("User may delete user accounts", "用户可删除帐户");
regGS("Add new user account", "添加新帐户");
regGS("There are $1 issue(s) left.", "还有$1个问题");
regGS("There are $1 keyword(s) left.", "还有$1个关键字");
regGS("Name<BR><SMALL>(click to edit)</SMALL>", "名称（点击编辑）");
regGS("New field", "新字段");
regGS("Select All", "");
regGS("Select None", "");
regGS("Add Event", "");
regGS("N/A", "");
regGS("On Front Page", "");
regGS("On Section Page", "");
regGS("Created by", "");
regGS("Creation date", "");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/zh/globals.php <==
<?php 
regGS("Account", "");
regGS("Items per page", "");
regGS("Add new", "");
regGS("Campsite", "CAMPSITE");
regGS("Home", "首页");
regGS("Logout", "注销");
regGS("More...", "");
regGS("Content", "");
regGS("Languages", "语言");
regGS("Countries", "国家");
regGS("Templates", "模版");
regGS("Topics", "主题");
regGS("Configure", "");
regGS("Image Archive", "");
regGS("Add Article", "");
regGS("Fields", "字段");
regGS("Delete", "删除");
regGS("Type", "输入");
regGS("Name", "名称");
regGS("Code", "号码");
regGS("Edit", "编辑");
regGS("Login", "登陆");
regGS("Password", "密码");
regGS("Site", "地址");
regGS("Path", "路径");
regGS("Go up", "向上");
regGS("URL", "");
regGS("Order", "");
regGS("Hide", "");
regGS("Duplicate", "复制");
regGS("Subscription", "");
regGS("expires", "");
regGS("starts", "");
regGS("before", "");
regGS("after", "");
regGS("on", "");
regGS("status", "");
regGS("active", "");
regGS("inactive", "");
regGS("Subscribers", "");
regGS("Staff", "");
regGS("Select destination", "");
regGS("No languages", "无语言");
regGS("---Select language---", "－－选择语言－－");
regGS("No publications", "无出版物");
regGS("---Select publication---", "－－选择出版物－－");
regGS("No issues", "无议题");
regGS("---Select issue---", "－－选择议题－－");
regGS("No sections", "无区");
regGS("---Select section---", "－－选择区－－");
regGS("No articles", "无文章");
regGS("---Select article---", "－－选择文章－－");
regGS("Language", "语言");
regGS("Country", "国家");
regGS("Account name", "");
regGS("Publication", "出版物");
regGS("Default language", "默认语言");
regGS("Subscriptions", "订阅");
regGS("Issue", "问题");
regGS("Number", "数字");
regGS("Section", "区");
regGS("Keywords", "关键词");
regGS("Topic", "主题");
regGS("URL Name", "");
regGS("Left to pay", "");
regGS("Active", "");
regGS("Trial", "");
regGS("Next", "下一个");
regGS("Previous", "上一个");
regGS("Translate", "翻译");
regGS("View", "查看");
regGS("Scheduled Publishing", "");
regGS("Time", "");
regGS("Action", "");
regGS("Schedule a new action", "");
regGS("Scheduling a new publish action", "");
regGS("Delete scheduled publish action", "");
regGS("Date/Time", "");
regGS("You must select an action.", "");
regGS("You do not have the right to schedule issues or articles for automatic publishing.", "");
regGS("Front page", "");
regGS("Section page", "");
regGS("Show on front page", "");
regGS("Remove from front page", "");
regGS("Show on section page", "");
regGS("Remove from section page", "");
regGS("Actions", "");
regGS("Publishing", "");
regGS("Show", "");
regGS("Remove", "");
regGS("Article Types", "文章类型");
regGS("Staff User Types", "");
regGS("Publications", "出版物");
regGS("Issues", "问题");
regGS("Sections", "区域");
regGS("Articles", "文章");
regGS("Images", "图片");
regGS("Change", "变化");
regGS("Add new issue", "添加新论题");
regGS("Section Template", "");
regGS("Article Template", "");
regGS("Default Language", "默认语言");
regGS("Paid Period", "已付期");
regGS("Preview", "预览");
regGS("You must complete the $1 field.", "您必须完成$1字段");
regGS("Error", "");
regGS("Invalid input: $1", "");
regGS("Language does not exist.", "");
regGS("Publication does not exist.", "无此出版物");
regGS("Issue does not exist.", "");
regGS("You must select a language.", "您必须选择一种语言");
regGS("Section does not exist.", "");
regGS("No articles.", "无此文字");
regGS("Article does not exist.", "");
regGS("Image does not exist.", "");
regGS("Access denied", "拒绝访问");
regGS("Invalid parameters received", "");
regGS("Add new article", "添加新文章");
regGS("Status", "状态");
regGS("Published", "已发布");
regGS("Not published", "未发布");
regGS("Submitted", "已提交");
regGS("New", "新");
regGS("Article", "文章");
regGS("Publish", "发布");
regGS("Unpublish", "不发布");
regGS("Unlock", "解锁");
regGS("Uploaded", "已上载");
regGS("(yyyy-mm-dd)", "yyyy-mm-dd");
regGS("YYYY-MM-DD", "YYYY-MM-DD");
regGS("Submit", "提交");
regGS("Image", "图片");
regGS("Description", "描述");
regGS("Photographer", "摄影");
regGS("Place", "地点");
regGS("Date", "日期");
regGS("Thumbnail", "");
regGS("In use", "");
regGS("Additional searches", "");
regGS("Most Recently Added", "");
regGS("Most Recently Modified", "");
regGS("$1 images found", "");
regGS("Reset search conditions", "");
regGS("Image number", "图片号码");
regGS("Users", "用户");
regGS("Restart the template engine", "");
regGS("The template engine was (re)started.", "");
regGS("The template engine could not be restarted! Please verify if the template engine was started by other user than $1.", "");
regGS("Localizer", "");
regGS("Adding new translation", "添加新翻译");
regGS("No more languages.", "无更多语言");
regGS("The $1 field may only contain letters, digits and underscore (_) character.", "");
regGS("Add new publication", "添加新发布");
regGS("Upload new template", "上载新模版");
regGS("Add new staff member", "");
regGS("Add new subscriber", "");
regGS("Add new user type", "添加新用户类型");
regGS("Add new article type", "添加新文章类型");
regGS("Add new country", "添加新国家");
regGS("Add new language", "添加新语言");
regGS("View logs", "查看日志");
regGS("Change your password", "修改你的密码");
regGS("Your Articles", "你的文章");
regGS("Submitted Articles", "提交文章");
regGS("Logs", "日志");
regGS("There are $1 article(s) left.", "还有$1篇文章");
regGS("There are $1 issues(s) left.", "");
regGS("There are $1 section(s) left.", "还有$1区");
regGS("There are $1 publication(s) left.", "还有$1发布");
regGS("There are $1 countries left.", "还有$1个国家");
regGS("Name <SMALL>(click to edit)</SMALL>", "");
regGS("Add new subscription", "添加新订阅");
regGS("You do not have the right to add subscriptions.", "你没有添加订阅的权限");
regGS("Adding subscription", "添加订阅");
regGS("Delete subscription", "删除订阅");
regGS("You do not have the right to delete subscriptions.", "你没有删除订阅的权限");
regGS("No such subscription.", "无此订阅");
regGS("Yes", "是");
regGS("No", "否");
regGS("Close", "");
regGS("No issues.", "无问题");
regGS("Back to Edit Article", "");
regGS("No topics", "无主题");
regGS("You must fill in the $1 field.", "你必须填写$1字段");
regGS("You do not have the right to add articles.", "您无权添加文章");
regGS("Start", "开始");
regGS("Days", "天数");
regGS("(YYYY-MM-DD)", "YYYY-MM-DD");
regGS("The sections could not be added successfully. Some of them were already added !", "区未成功添加，其中一些已经存在");
regGS("Add another", "添加另一个");
regGS("Cancel", "取消");
regGS("Done", "完成");
regGS("OK", "成功");
regGS("Save", "");
regGS("Search", "搜索");
regGS("Make a selection", "");
regGS("You must input a number greater than 0 into the $1 field.", "");
regGS("You must input a valid date.", "");
regGS("Add new field", "增加新字段");
regGS("Article automatic publishing schedule", "");
regGS("Are you sure you want to delete this scheduled action?", "");
regGS("Unlink", "");
regGS("Are you sure you want to delete the image \'$1\'?", "");
regGS("No such issue.", "无此问题");
regGS("Are you sure you want to delete the subscription to the publication $1?", "");
regGS("Could not save the changes to the issue $1. Please make sure the issue URL name '$2' was not used before in the publication $3.", "");
regGS("GB", "");
regGS("MB", "");
regGS("KB", "");
regGS("bytes", "");
regGS("Attach", "");
regGS("Back", "");
regGS("File", "");
regGS("Save and Close", "");
regGS("Add", "增加");
regGS("User name", "用户名");
regGS("User Types", "用户类型");
regGS("Subscription Default Time", "默认订阅时间");
regGS("No such language.", "无此语言");
regGS("No such infotype.", "无此类型");
regGS("No such keyword.", "无此关键字");
regGS("No such country.", "无此国家");
regGS("User may add/change user accounts and passwords", "用户可添加/删除帐户与密码");
regGS("User may delete user accounts", "用户可删除帐户");
regGS("Add new user account", "添加新帐户");
regGS("There are $1 issue(s) left.", "还有$1个问题");
regGS("There are $1 keyword(s) left.", "还有$1个关键字");
regGS("Name<BR><SMALL>(click to edit)</SMALL>", "名称（点击编辑）");
regGS("New field", "新字段");
regGS("Select All", "");
regGS("Select None", "");
regGS("Add Event", "");
regGS("N/A", "");
regGS("On Front Page", "");
regGS("On Section Page", "");
regGS("Created by", "");
regGS("Creation date", "");
regGS("Publication List", "");
regGS("Issue List", "");
regGS("Section List", "");
regGS("All", "");
regGS("duplicate", "");
regGS("move", "");
regGS("Move", "");
regGS("From:", "");
regGS("Date:", "");
regGS("Hidden", "");
regGS("Comments", "");
regGS("Comment", "");
regGS("Approved", "");
regGS("Comment:", "");
regGS("Subject:", "");
regGS("Subject", "");
regGS("Name:", "");
regGS("IP address:", "");
regGS("Email:", "");
regGS("Author:", "");
regGS("Author", "");
regGS("Article name", "");
regGS("Hide article", "");
regGS("Show article", "");
regGS("Log Messages", "");
regGS("Article Files", "");
regGS("Article Comments", "");
regGS("Are you sure you want to deactivate the subscription?", "");
regGS("Are you sure you want to activate the subscription?", "");
regGS("Other", "");
regGS("No events.", "");
regGS("Default templates", "");
regGS("System Preferences", "");
regGS("The date must be in the future.", "");
regGS("Send", "");
regGS("Thank you.", "");
regGS("Please take a minute to send us an email.", "");
regGS("(optional)", "");
regGS("The URL you entered is invalid: '$1'", "");
?>
